Module artifact

Module artifact 

List of artifacts.

Structs

JsonTrace
modelator’s artifact containing a test trace encoded as JSON.
ModelCheckerStdout
Ultra-basic wrapper around stdout of model checker execution NOTE: This is a stand in and will be changed soon.
TlaConfigFile
modelator’s artifact representing a TLA+ config file containing the TLA+ model CONSTANTs and INIT and NEXT predicates.
TlaFile
modelator’s artifact representing a TLA+ file.
TlaFileSuite
TODO: split module and cfg into two parts and contain the main module and extended modules in module struct An in-memory representation of all the resources needed to perform model checking Includes the main .tla and .cfg files as well as depended on (via EXTENDS) .tla files.
TlaTrace
modelator’s artifact containing a test trace encoded as TLA+.

Traits

Artifact
A wrapper around a file NOTE: for now this is bare-bones but it will eventually include additional meta-data which will justify the additional interface.
ArtifactCreator
A sister trait for Artifacts for static constructor methods NOTE: static methods and polymorphic methods prevent trait-object instantiation so this approach allows dynamic use of Artifacts
ArtifactSaver
An artifact which is a file It can be saved in a directory, as it has its own filename

Functions

try_write_to_dir
Try to write each artifact in any object implementing into_iter for Artifacts to the given directory