ArtifactSaver

Trait ArtifactSaver 

pub trait ArtifactSaver: Artifact {
    // Required method
    fn filename(&self) -> String;

    // Provided method
    fn try_write_to_dir(&self, path: &Path) -> Result<PathBuf, Error> { ... }
}
An artifact which is a file It can be saved in a directory, as it has its own filename

Required Methods

fn filename(&self) -> String

Returns filename

Provided Methods

fn try_write_to_dir(&self, path: &Path) -> Result<PathBuf, Error>

Tries to save the contents to directory using the file name

Implementors