pub trait StateHandler<State> {
// Required methods
fn init(&mut self, state: State);
fn read(&self) -> State;
}Expand description
A trait for handling the mapping between abstract and concrete system states It is supposed that the tests are described in terms of a (much simpler) abstract state, with a lot less components than the concrete system state being tested.
A concrete system state can be partitioned into several state subspaces, With separate abstract state describing each concrete state subspace.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".