pub struct ApalacheError { /* private fields */ }Expand description
Contains an Apalache stdout string together with a summary string containing either the line of a matched error, or a string explaining that no error match was found.