pub struct EventRunner<System: Debug> { /* private fields */ }Expand description
A runner that allows to run tests specified as event streams
against the given concrete system.
You can implement several instances of StateHandlers
and ActionHandlers for the System, thus allowing your system
to handle several kinds of abstract states or actions.
Implementations
Sourceimpl<System: Debug> EventRunner<System>
impl<System: Debug> EventRunner<System>
Sourcepub fn with_state<State>(self) -> Selfwhere
State: 'static + DeserializeOwned + UnwindSafe + Clone + Debug + PartialEq,
System: 'static + StateHandler<State>,
pub fn with_state<State>(self) -> Selfwhere
State: 'static + DeserializeOwned + UnwindSafe + Clone + Debug + PartialEq,
System: 'static + StateHandler<State>,
Equip the runner with the ability to handle given abstract State.
Sourcepub fn with_action<Action>(self) -> Selfwhere
Action: 'static + DeserializeOwned + UnwindSafe + Clone,
System: 'static + ActionHandler<Action>,
<System as ActionHandler<Action>>::Outcome: 'static + Serialize,
pub fn with_action<Action>(self) -> Selfwhere
Action: 'static + DeserializeOwned + UnwindSafe + Clone,
System: 'static + ActionHandler<Action>,
<System as ActionHandler<Action>>::Outcome: 'static + Serialize,
Equip the runner with the ability to handle given abstract Action.
Sourcepub fn run(
&mut self,
system: &mut System,
stream: &mut dyn Iterator<Item = Event>,
) -> Result<(), TestError>
pub fn run( &mut self, system: &mut System, stream: &mut dyn Iterator<Item = Event>, ) -> Result<(), TestError>
Run the runner on:
- the given concrete
system, which provides storage of concrete system states, as well as the handling of the abstract states and actions; - the given stream of events, representing the test.
Returns the test result.