StateHandler

Trait StateHandler 

pub trait StateHandler<State> {
    // Required methods
    fn init(&mut self, state: State);
    fn read(&self) -> State;
}
A trait for handling the mapping between abstract and concrete system states It is supposed that the tests are described in terms of a (much simpler) abstract state, with a lot less components than the concrete system state being tested.

A concrete system state can be partitioned into several state subspaces, With separate abstract state describing each concrete state subspace.

Required Methods

fn init(&mut self, state: State)

Initialize concrete state from the abstract one. Should completely reinitialize the concrete state when called. Guaranteed to be called at the beginning of each test.

fn read(&self) -> State

Read the concrete state into the abstract one.

Implementors