Testing utilities
Structs
- Number
System - Example system under test (SUT).
Allows to modify the two variables, a and b,
if they do not exceed the
MAX_NUMBER. Maintains also the sum and product of the variables.
Testing utilities
MAX_NUMBER.
Maintains also the sum and product of the variables.